# motifcluster 0.2.0 (2022-04-28)

- Bump version to keep track with R

# motifcluster 0.1.2 (2021-11-11)

- Adding license file to PyPI distribution

# motifcluster 0.1.1 (2020-08-10)

- Rewriting dense MAM construction methods using Numpy

# motifcluster 0.1.0 (2020-05-08)

- Updates and corrections to tutorials
- Added performance tests

# motifcluster 0.0.2 (2020-04-30)

- Implemented faster methods for network sampling
- Minor fixes in tutorial

# motifcluster 0.0.1 (2020-04-26)

- Initial development release
